import { scaleLinear, scaleTime, line, extent } from 'd3';
import { axes } from '@drbagwell/responsive-viz-axes';

export const viz = (
  svg,
  {
    data,
    xValue,
    xAxisLabelText,
    xAxisLabelOffset,
    yValue,
    yAxisLabelText,
    yAxisLabelOffset,
    marginLeft,
    marginTop,
    marginRight,
    marginBottom,
    width,
    height,
    circleRadius,
    circleOpacity,
    innerRectFill,
  },
) => {
  const xScale = scaleTime(extent(data, xValue), [
    marginLeft,
    width - marginRight,
  ]);

  const yScale = scaleLinear(extent(data, yValue), [
    height - marginBottom,
    marginTop,
  ]);

  const innerWidth = width - marginLeft - marginRight;
  const innerHeight = height - marginTop - marginBottom;

  // initial Canvas Drawing Region
  svg
    .selectAll('rect')
    .data([null])
    .join('rect')
    .attr('x', marginLeft)
    .attr('y', marginTop)
    .attr('width', innerWidth)
    .attr('height', innerHeight)
    .attr('fill', innerRectFill);

  axes(svg, {
    width,
    height,
    xScale,
    xAxisLabelOffset,
    xAxisLabelText,
    yScale,
    yAxisLabelText,
    yAxisLabelOffset,
    marginLeft,
    marginBottom,
  });

  const lineGenerator = line(
    (d) => xScale(xValue(d)),
    (d) => yScale(yValue(d)),
  ).defined(yValue);

  //  A line
  svg
    .selectAll('path.mark')
    .data([null])
    .join('path')
    .attr('class', 'mark')
    .attr('fill', 'none')
    .attr('stroke', 'black')
    .attr('d', lineGenerator(data));
};
